@@ -12,8 +12,6 @@ import itertools
 import numbers
 import re
 import string
-import warnings
-from collections import deque
 from collections.abc import Iterable, Iterator
 from functools import lru_cache, partial
 from re import Match
@@ -24,7 +22,7 @@ import astroid.objects
 from astroid import TooManyLevelsError, nodes, util
 from astroid.context import InferenceContext
 from astroid.exceptions import AstroidError
-from astroid.nodes._base_nodes import ImportNode
+from astroid.nodes._base_nodes import ImportNode, Statement
 from astroid.typing import InferenceResult, SuccessfulInferenceResult
 
 if TYPE_CHECKING:
@@ -249,17 +247,6 @@ class InferredTypeError(Exception):
     pass
 
 
-def is_inside_lambda(node: nodes.NodeNG) -> bool:
-    """Return whether the given node is inside a lambda."""
-    warnings.warn(
-        "utils.is_inside_lambda will be removed in favour of calling "
-        "utils.get_node_first_ancestor_of_type(x, nodes.Lambda) in pylint 3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
-    return any(isinstance(parent, nodes.Lambda) for parent in node.node_ancestors())
-
-
 def get_all_elements(
     node: nodes.NodeNG,
 ) -> Iterable[nodes.NodeNG]:
@@ -369,9 +356,10 @@ def is_defined_before(var_node: nodes.Name) -> bool:
         if defnode is None:
             continue
         defnode_scope = defnode.scope()
-        if isinstance(defnode_scope, COMP_NODE_TYPES + (nodes.Lambda,)):
+        if isinstance(
+            defnode_scope, (*COMP_NODE_TYPES, nodes.Lambda, nodes.FunctionDef)
+        ):
             # Avoid the case where var_node_scope is a nested function
-            # FunctionDef is a Lambda until https://github.com/pylint-dev/astroid/issues/291
             if isinstance(defnode_scope, nodes.FunctionDef):
                 var_node_scope = var_node.scope()
                 if var_node_scope is not defnode_scope and isinstance(
@@ -391,14 +379,13 @@ def is_defined_before(var_node: nodes.Name) -> bool:
                     nodes.For,
                     nodes.While,
                     nodes.With,
-                    nodes.TryExcept,
-                    nodes.TryFinally,
+                    nodes.Try,
                     nodes.ExceptHandler,
                 ),
             ):
                 return True
     # possibly multiple statements on the same line using semicolon separator
-    stmt = var_node.statement(future=True)
+    stmt = var_node.statement()
     _node = stmt.previous_sibling()
     lineno = stmt.fromlineno
     while _node and _node.fromlineno == lineno:
@@ -505,25 +492,6 @@ def only_required_for_messages(
     return store_messages
 
 
-def check_messages(
-    *messages: str,
-) -> Callable[
-    [AstCallbackMethod[_CheckerT, _NodeT]], AstCallbackMethod[_CheckerT, _NodeT]
-]:
-    """Kept for backwards compatibility, deprecated.
-
-    Use only_required_for_messages instead, which conveys the intent of the decorator much clearer.
-    """
-    warnings.warn(
-        "utils.check_messages will be removed in favour of calling "
-        "utils.only_required_for_messages in pylint 3.0",
-        DeprecationWarning,
-        stacklevel=2,
-    )
-
-    return only_required_for_messages(*messages)
-
-
 class IncompleteFormatString(Exception):
     """A format string ended in the middle of a format specifier."""
 
@@ -703,7 +671,7 @@ def node_frame_class(node: nodes.NodeNG) -> nodes.ClassDef | None:
     The function returns a class for a method node (or a staticmethod or a
     classmethod), otherwise it returns `None`.
     """
-    klass = node.frame(future=True)
+    klass = node.frame()
     nodes_to_check = (
         nodes.NodeNG,
         astroid.UnboundMethod,
@@ -717,14 +685,14 @@ def node_frame_class(node: nodes.NodeNG) -> nodes.ClassDef | None:
         if klass.parent is None:
             return None
 
-        klass = klass.parent.frame(future=True)
+        klass = klass.parent.frame()
 
     return klass
 
 
 def get_outer_class(class_node: astroid.ClassDef) -> astroid.ClassDef | None:
     """Return the class that is the outer class of given (nested) class_node."""
-    parent_klass = class_node.parent.frame(future=True)
+    parent_klass = class_node.parent.frame()
 
     return parent_klass if isinstance(parent_klass, astroid.ClassDef) else None
 
@@ -966,7 +934,7 @@ def uninferable_final_decorators(
 
 @lru_cache(maxsize=1024)
 def unimplemented_abstract_methods(
-    node: nodes.ClassDef, is_abstract_cb: nodes.FunctionDef = None
+    node: nodes.ClassDef, is_abstract_cb: nodes.FunctionDef | None = None
 ) -> dict[str, nodes.FunctionDef]:
     """Get the unimplemented abstract methods for the given *node*.
 
@@ -1019,10 +987,10 @@ def unimplemented_abstract_methods(
 
 def find_try_except_wrapper_node(
     node: nodes.NodeNG,
-) -> nodes.ExceptHandler | nodes.TryExcept | None:
-    """Return the ExceptHandler or the TryExcept node in which the node is."""
+) -> nodes.ExceptHandler | nodes.Try | None:
+    """Return the ExceptHandler or the Try node in which the node is."""
     current = node
-    ignores = (nodes.ExceptHandler, nodes.TryExcept)
+    ignores = (nodes.ExceptHandler, nodes.Try)
     while current and not isinstance(current.parent, ignores):
         current = current.parent
 
@@ -1033,7 +1001,7 @@ def find_try_except_wrapper_node(
 
 def find_except_wrapper_node_in_scope(
     node: nodes.NodeNG,
-) -> nodes.ExceptHandler | nodes.TryExcept | None:
+) -> nodes.ExceptHandler | None:
     """Return the ExceptHandler in which the node is, without going out of scope."""
     for current in node.node_ancestors():
         if isinstance(current, astroid.scoped_nodes.LocalsDictNodeNG):
@@ -1093,7 +1061,7 @@ def get_exception_handlers(
         list: the collection of handlers that are handling the exception or None.
     """
     context = find_try_except_wrapper_node(node)
-    if isinstance(context, nodes.TryExcept):
+    if isinstance(context, nodes.Try):
         return [
             handler for handler in context.handlers if error_of_type(handler, exception)
         ]
@@ -1164,13 +1132,13 @@ def is_node_inside_try_except(node: nodes.Raise) -> bool:
         bool: True if the node is inside a try/except statement, False otherwise.
     """
     context = find_try_except_wrapper_node(node)
-    return isinstance(context, nodes.TryExcept)
+    return isinstance(context, nodes.Try)
 
 
 def node_ignores_exception(
     node: nodes.NodeNG, exception: type[Exception] | str = Exception
 ) -> bool:
-    """Check if the node is in a TryExcept which handles the given exception.
+    """Check if the node is in a Try which handles the given exception.
 
     If the exception is not given, the function is going to look for bare
     excepts.
@@ -1181,6 +1149,7 @@ def node_ignores_exception(
     return any(get_contextlib_suppressors(node, exception))
 
 
+@lru_cache(maxsize=1024)
 def class_is_abstract(node: nodes.ClassDef) -> bool:
     """Return true if the given class node should be considered as an abstract
     class.
@@ -1201,7 +1170,7 @@ def class_is_abstract(node: nodes.ClassDef) -> bool:
             return True
 
     for method in node.methods():
-        if method.parent.frame(future=True) is node:
+        if method.parent.frame() is node:
             if method.is_abstract(pass_is_abstract=False):
                 return True
     return False
@@ -1411,12 +1380,10 @@ def safe_infer(
                 return None
             if (
                 isinstance(inferred, nodes.FunctionDef)
-                and inferred.args.args is not None
                 and isinstance(value, nodes.FunctionDef)
-                and value.args.args is not None
-                and len(inferred.args.args) != len(value.args.args)
+                and function_arguments_are_ambiguous(inferred, value)
             ):
-                return None  # Different number of arguments indicates ambiguity
+                return None
     except astroid.InferenceError:
         return None  # There is some kind of ambiguity
     except StopIteration:
@@ -1438,6 +1405,33 @@ def infer_all(
         raise AstroidError from e
 
 
+def function_arguments_are_ambiguous(
+    func1: nodes.FunctionDef, func2: nodes.FunctionDef
+) -> bool:
+    if func1.argnames() != func2.argnames():
+        return True
+    # Check ambiguity among function default values
+    pairs_of_defaults = [
+        (func1.args.defaults, func2.args.defaults),
+        (func1.args.kw_defaults, func2.args.kw_defaults),
+    ]
+    for zippable_default in pairs_of_defaults:
+        if None in zippable_default:
+            continue
+        if len(zippable_default[0]) != len(zippable_default[1]):
+            return True
+        for default1, default2 in zip(*zippable_default):
+            if isinstance(default1, nodes.Const) and isinstance(default2, nodes.Const):
+                if default1.value != default2.value:
+                    return True
+            elif isinstance(default1, nodes.Name) and isinstance(default2, nodes.Name):
+                if default1.name != default2.name:
+                    return True
+            else:
+                return True
+    return False
+
+
 def has_known_bases(
     klass: nodes.ClassDef, context: InferenceContext | None = None
 ) -> bool:
@@ -1591,27 +1585,6 @@ def is_postponed_evaluation_enabled(node: nodes.NodeNG) -> bool:
     return "annotations" in module.future_imports
 
 
-def is_class_subscriptable_pep585_with_postponed_evaluation_enabled(
-    value: nodes.ClassDef, node: nodes.NodeNG
-) -> bool:
-    """Check if class is subscriptable with PEP 585 and
-    postponed evaluation enabled.
-    """
-    warnings.warn(
-        "'is_class_subscriptable_pep585_with_postponed_evaluation_enabled' has been "
-        "deprecated and will be removed in pylint 3.0. "
-        "Use 'is_postponed_evaluation_enabled(node) and "
-        "is_node_in_type_annotation_context(node)' instead.",
-        DeprecationWarning,
-        stacklevel=2,
-    )
-    return (
-        is_postponed_evaluation_enabled(node)
-        and value.qname() in SUBSCRIPTABLE_CLASSES_PEP585
-        and is_node_in_type_annotation_context(node)
-    )
-
-
 def is_node_in_type_annotation_context(node: nodes.NodeNG) -> bool:
     """Check if node is in type annotation context.
 
@@ -1862,48 +1835,6 @@ def is_sys_guard(node: nodes.If) -> bool:
     return False
 
 
-def is_typing_guard(node: nodes.If) -> bool:
-    """Return True if IF stmt is a typing guard.
-
-    >>> from typing import TYPE_CHECKING
-    >>> if TYPE_CHECKING:
-    >>>     from xyz import a
-    """
-    warnings.warn(
-        "This method will be removed in pylint 3.0; use in_type_checking_block() instead.",
-        DeprecationWarning,
-        stacklevel=2,
-    )  # pragma: no cover
-    return isinstance(
-        node.test, (nodes.Name, nodes.Attribute)
-    ) and node.test.as_string().endswith("TYPE_CHECKING")
-
-
-def is_node_in_typing_guarded_import_block(node: nodes.NodeNG) -> bool:
-    """Return True if node is part for guarded `typing.TYPE_CHECKING` if block."""
-    warnings.warn(
-        "This method will be removed in pylint 3.0; use in_type_checking_block() instead.",
-        DeprecationWarning,
-        stacklevel=2,
-    )  # pragma: no cover
-    return isinstance(node.parent, nodes.If) and is_typing_guard(node.parent)
-
-
-def is_node_in_guarded_import_block(node: nodes.NodeNG) -> bool:
-    """Return True if node is part for guarded if block.
-
-    I.e. `sys.version_info` or `typing.TYPE_CHECKING`
-    """
-    warnings.warn(
-        "This method will be removed in pylint 3.0; use in_type_checking_block() instead.",
-        DeprecationWarning,
-        stacklevel=2,
-    )  # pragma: no cover
-    return isinstance(node.parent, nodes.If) and (
-        is_sys_guard(node.parent) or is_typing_guard(node.parent)
-    )
-
-
 def is_reassigned_after_current(node: nodes.NodeNG, varname: str) -> bool:
     """Check if the given variable name is reassigned in the same scope after the
     current node.
@@ -1986,7 +1917,7 @@ def get_node_first_ancestor_of_type_and_its_child(
     descendant visited directly before reaching the sought ancestor.
 
     Useful for extracting whether a statement is guarded by a try, except, or finally
-    when searching for a TryFinally ancestor.
+    when searching for a Try ancestor.
     """
     child = node
     for ancestor in node.node_ancestors():
@@ -2054,8 +1985,8 @@ def is_typing_member(node: nodes.NodeNG, names_to_check: tuple[str, ...]) -> boo
     return False
 
 
-@lru_cache()
-def in_for_else_branch(parent: nodes.NodeNG, stmt: nodes.Statement) -> bool:
+@lru_cache
+def in_for_else_branch(parent: nodes.NodeNG, stmt: Statement) -> bool:
     """Returns True if stmt is inside the else branch for a parent For stmt."""
     return isinstance(parent, nodes.For) and any(
         else_stmt.parent_of(stmt) or else_stmt == stmt for else_stmt in parent.orelse
@@ -2110,6 +2041,23 @@ def is_hashable(node: nodes.NodeNG) -> bool:
         return True
 
 
+def subscript_chain_is_equal(left: nodes.Subscript, right: nodes.Subscript) -> bool:
+    while isinstance(left, nodes.Subscript) and isinstance(right, nodes.Subscript):
+        try:
+            if (
+                get_subscript_const_value(left).value
+                != get_subscript_const_value(right).value
+            ):
+                return False
+
+            left = left.value
+            right = right.value
+        except InferredTypeError:
+            return False
+
+    return left.as_string() == right.as_string()  # type: ignore[no-any-return]
+
+
 def _is_target_name_in_binop_side(
     target: nodes.AssignName | nodes.AssignAttr, side: nodes.NodeNG | None
 ) -> bool:
@@ -2120,6 +2068,9 @@ def _is_target_name_in_binop_side(
         return False
     if isinstance(side, nodes.Attribute) and isinstance(target, nodes.AssignAttr):
         return target.as_string() == side.as_string()  # type: ignore[no-any-return]
+    if isinstance(side, nodes.Subscript) and isinstance(target, nodes.Subscript):
+        return subscript_chain_is_equal(target, side)
+
     return False
 
 
@@ -2134,7 +2085,7 @@ def is_augmented_assign(node: nodes.Assign) -> tuple[bool, str]:
     binop = node.value
     target = node.targets[0]
 
-    if not isinstance(target, (nodes.AssignName, nodes.AssignAttr)):
+    if not isinstance(target, (nodes.AssignName, nodes.AssignAttr, nodes.Subscript)):
         return False, ""
 
     # We don't want to catch x = "1" + x or x = "%s" % x
@@ -2163,37 +2114,30 @@ def is_augmented_assign(node: nodes.Assign) -> tuple[bool, str]:
     return False, ""
 
 
+def _qualified_name_parts(qualified_module_name: str) -> list[str]:
+    """Split the names of the given module into subparts.
+
+    For example,
+        _qualified_name_parts('pylint.checkers.ImportsChecker')
+    returns
+        ['pylint', 'pylint.checkers', 'pylint.checkers.ImportsChecker']
+    """
+    names = qualified_module_name.split(".")
+    return [".".join(names[0 : i + 1]) for i in range(len(names))]
+
+
 def is_module_ignored(
-    module: nodes.Module,
-    ignored_modules: Iterable[str],
+    qualified_module_name: str, ignored_modules: Iterable[str]
 ) -> bool:
     ignored_modules = set(ignored_modules)
-    module_name = module.name
-    module_qname = module.qname()
-
-    for ignore in ignored_modules:
-        # Try to match the module name / fully qualified name directly
-        if module_qname in ignored_modules or module_name in ignored_modules:
+    for current_module in _qualified_name_parts(qualified_module_name):
+        # Try to match the module name directly
+        if current_module in ignored_modules:
             return True
-
-        # Try to see if the ignores pattern match against the module name.
-        if fnmatch.fnmatch(module_qname, ignore):
-            return True
-
-        # Otherwise, we might have a root module name being ignored,
-        # and the qualified owner has more levels of depth.
-        parts = deque(module_name.split("."))
-        current_module = ""
-
-        while parts:
-            part = parts.popleft()
-            if not current_module:
-                current_module = part
-            else:
-                current_module += f".{part}"
-            if current_module in ignored_modules:
+        for ignore in ignored_modules:
+            # Try to see if the ignores pattern match against the module name.
+            if fnmatch.fnmatch(current_module, ignore):
                 return True
-
     return False
 
 
@@ -2233,53 +2177,6 @@ def is_class_attr(name: str, klass: nodes.ClassDef) -> bool:
         return False
 
 
-def is_defined(name: str, node: nodes.NodeNG) -> bool:
-    """Searches for a tree node that defines the given variable name."""
-    is_defined_so_far = False
-
-    if isinstance(node, nodes.NamedExpr):
-        is_defined_so_far = node.target.name == name
-
-    if isinstance(node, (nodes.Import, nodes.ImportFrom)):
-        is_defined_so_far = any(node_name[0] == name for node_name in node.names)
-
-    if isinstance(node, nodes.With):
-        is_defined_so_far = any(
-            isinstance(item[1], nodes.AssignName) and item[1].name == name
-            for item in node.items
-        )
-
-    if isinstance(node, (nodes.ClassDef, nodes.FunctionDef)):
-        is_defined_so_far = node.name == name
-
-    if isinstance(node, nodes.AnnAssign):
-        is_defined_so_far = (
-            node.value
-            and isinstance(node.target, nodes.AssignName)
-            and node.target.name == name
-        )
-
-    if isinstance(node, nodes.Assign):
-        is_defined_so_far = any(
-            any(
-                (
-                    (
-                        isinstance(elt, nodes.Starred)
-                        and isinstance(elt.value, nodes.AssignName)
-                        and elt.value.name == name
-                    )
-                    or (isinstance(elt, nodes.AssignName) and elt.name == name)
-                )
-                for elt in get_all_elements(target)
-            )
-            for target in node.targets
-        )
-
-    return is_defined_so_far or any(
-        is_defined(name, child) for child in node.get_children()
-    )
-
-
 def get_inverse_comparator(op: str) -> str:
     """Returns the inverse comparator given a comparator.
 
@@ -2336,12 +2233,30 @@ def not_condition_as_string(
     return msg
 
 
+@lru_cache(maxsize=1000)
+def overridden_method(
+    klass: nodes.LocalsDictNodeNG, name: str | None
+) -> nodes.FunctionDef | None:
+    """Get overridden method if any."""
+    try:
+        parent = next(klass.local_attr_ancestors(name))
+    except (StopIteration, KeyError):
+        return None
+    try:
+        meth_node = parent[name]
+    except KeyError:  # pragma: no cover
+        # We have found an ancestor defining <name> but it's not in the local
+        # dictionary. This may happen with astroid built from living objects.
+        return None
+    if isinstance(meth_node, nodes.FunctionDef):
+        return meth_node
+    return None  # pragma: no cover
+
+
 def clear_lru_caches() -> None:
     """Clear caches holding references to AST nodes."""
-    # pylint: disable-next=import-outside-toplevel
-    from pylint.checkers.variables import overridden_method
-
     caches_holding_node_references: list[_lru_cache_wrapper[Any]] = [
+        class_is_abstract,
         in_for_else_branch,
         infer_all,
         is_overload_stub,
@@ -2351,3 +2266,23 @@ def clear_lru_caches() -> None:
     ]
     for lru in caches_holding_node_references:
         lru.cache_clear()
+
+
+def is_enum_member(node: nodes.AssignName) -> bool:
+    """Return `True` if `node` is an Enum member (is an item of the
+    `__members__` container).
+    """
+
+    frame = node.frame()
+    if (
+        not isinstance(frame, nodes.ClassDef)
+        or not frame.is_subtype_of("enum.Enum")
+        or frame.root().qname() == "enum"
+    ):
+        return False
+
+    members = frame.locals.get("__members__")
+    # A dataclass is one known case for when `members` can be `None`
+    if members is None:
+        return False
+    return node.name in [name_obj.name for value, name_obj in members[0].items]
