@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 from __future__ import annotations
 
@@ -23,11 +23,13 @@ class ConfusingConsecutiveElifChecker(BaseChecker):
     name = "confusing_elif"
     msgs = {
         "R5601": (
-            "Consecutive elif with differing indentation level, consider creating a function to separate the inner elif",
+            "Consecutive elif with differing indentation level, consider creating a function to separate the inner"
+            " elif",
             "confusing-consecutive-elif",
             "Used when an elif statement follows right after an indented block which itself ends with if or elif. "
             "It may not be ovious if the elif statement was willingly or mistakenly unindented. "
-            "Extracting the indented if statement into a separate function might avoid confusion and prevent errors.",
+            "Extracting the indented if statement into a separate function might avoid confusion and prevent "
+            "errors.",
         )
     }
 
@@ -40,7 +42,7 @@ class ConfusingConsecutiveElifChecker(BaseChecker):
             self.add_message("confusing-consecutive-elif", node=node.orelse[0])
 
     @staticmethod
-    def _has_no_else_clause(node: nodes.If):
+    def _has_no_else_clause(node: nodes.If) -> bool:
         orelse = node.orelse
         while orelse and isinstance(orelse[0], nodes.If):
             orelse = orelse[0].orelse
