@@ -5,7 +5,6 @@
 from __future__ import annotations
 
 import sys
-import warnings
 from typing import TYPE_CHECKING, Any
 
 from astroid import nodes
@@ -71,23 +70,10 @@ class MessageDefinition:
         return f"MessageDefinition:{self.symbol} ({self.msgid})"
 
     def __str__(self) -> str:
-        return f"{repr(self)}:\n{self.msg} {self.description}"
+        return f"{self!r}:\n{self.msg} {self.description}"
 
-    def may_be_emitted(
-        self,
-        py_version: tuple[int, ...] | sys._version_info | None = None,
-    ) -> bool:
-        """Return True if message may be emitted using the configured py_version."""
-        if py_version is None:
-            py_version = sys.version_info
-            warnings.warn(
-                "'py_version' will be a required parameter of "
-                "'MessageDefinition.may_be_emitted' in pylint 3.0. The most likely "
-                "solution is to use 'linter.config.py_version' if you need to keep "
-                "using this function, or to use 'MessageDefinition.is_message_enabled'"
-                " instead.",
-                DeprecationWarning,
-            )
+    def may_be_emitted(self, py_version: tuple[int, ...] | sys._version_info) -> bool:
+        """May the message be emitted using the configured py_version?"""
         if self.minversion is not None and self.minversion > py_version:
             return False
         if self.maxversion is not None and self.maxversion <= py_version:
